@@ -12,6 +12,7 @@ from python_spartan.services.deployment import DeploymentService
 from python_spartan.services.handler import HandlerService
 from python_spartan.services.infrastructure import InfrastructureService
 from python_spartan.services.inspire import InspireService
+from python_spartan.services.layer import LayerService
 from python_spartan.services.migrate import MigrateService
 from python_spartan.services.model import ModelService
 from python_spartan.services.parser import ParserService
@@ -102,6 +103,9 @@ app.add_typer(
     infra_app, name="infra", help="Setup your serverless infrastructure as a code."
 )
 
+layer_app = typer.Typer()
+app.add_typer(layer_app, name="layer", help="Build and publish your AWS Lambda layers.")
+
 
 def run_poetry_command(command):
     try:
@@ -460,5 +464,52 @@ def create_dlq(
         print(f"Error creating DLQ: {e}")
 
 
+@layer_app.command("build", help="Pull packages and compress it.")
+def layer_create(
+    requirements_file: Optional[str] = typer.Option(
+        "requirements.txt", "--reqs", "-r", help="Path to the requirements file."
+    ),
+    venv: Optional[str] = typer.Option(
+        ".venv/lib", "--env", "-e", help="Path to the virtual environment lib."
+    ),
+    name: Optional[str] = typer.Option(
+        "spartan_lambda_layer", "--name", "-n", help="Name of the layer."
+    ),
+):
+    try:
+        layer_service = LayerService(requirements_file, venv, name)
+        layer_service.build_layer()
+    except Exception as e:
+        print(f"Error creating layer: {e}")
+
+
+# @layer_app.command("publish", help="Publish the layer to AWS.")
+# def layer_publish(
+#     name: str = typer.Argument(..., help="Name of the layer."),
+#     description: str = typer.Option(
+#         "", "--desc", "-d", help="Description of the layer."
+#     ),
+#     runtimes: str = typer.Option(
+#         "python3.11",
+#         "--runtimes",
+#         "-r",
+#         help="Compatible runtimes for the layer.",
+#     ),
+#     zip_file: str = typer.Option(
+#         ..., "--path", "-p", help="Path to the zip file to publish."
+#     ),
+# ):
+#     try:
+#         # Initialize LayerService with the name, description, and runtimes
+#         layer_service = LayerService(
+#             layer_name=name, description=description, compatible_runtimes=[runtimes]
+#         )
+#         # Publish the Lambda Layer using the provided zip file path
+#         layer_service.publish_layer(zip_file)
+#         print(f"Layer {name} published successfully.")
+#     except Exception as e:
+#         print(f"Error publishing layer: {e}")
+
+
 if __name__ == "__main__":
     app()
