@@ -12,7 +12,10 @@ class ApplicationService:
         self.repository_name = "spartan-framework"
 
     def is_valid_folder_name(self):
-        return all(c.isidentifier() or c == '-' for c in self.project_name) and not self.project_name[0].isdigit()
+        return (
+            all(c.isidentifier() or c == "-" for c in self.project_name)
+            and not self.project_name[0].isdigit()
+        )
 
     def download_zip(self):
         release_url = f"https://github.com/nerdmonkey/{self.repository_name}/archive/refs/heads/main.zip"
@@ -95,6 +98,7 @@ class ApplicationService:
         print(f"\nYour First Mission:")
         print(f"---------------")
         print(f"cd {self.project_name}")
+        print(f"python -m venv .venv")
         print(f"pip install -r requirements.txt")
         print(f"copy the .env.example and name it as .env")
         print(f"spartan migrate init -d sqlite")
